# coding: utf-8

"""
    Mentortools Deep Agent API

    FastAPI service for running Mentortools deep agent

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictInt

class RunUserContext(BaseModel):
    """
    User context for run creation.  # noqa: E501
    """
    id: StrictInt = Field(default=..., description="User ID")
    portal_id: StrictInt = Field(default=..., description="Portal ID")
    __properties = ["id", "portal_id"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> RunUserContext:
        """Create an instance of RunUserContext from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> RunUserContext:
        """Create an instance of RunUserContext from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return RunUserContext.parse_obj(obj)

        _obj = RunUserContext.parse_obj({
            "id": obj.get("id"),
            "portal_id": obj.get("portal_id")
        })
        return _obj


